pub enum Msg<Ctx: Context> {
Tick,
NetworkEvent(NetworkEvent<Ctx>),
Decided(Ctx::Height),
StartedHeight(Ctx::Height, bool),
GotDecidedValue(InboundRequestId, Ctx::Height, Option<RawDecidedValue<Ctx>>),
TimeoutElapsed(TimeoutElapsed<Timeout>),
InvalidValue(PeerId, Ctx::Height),
ValueProcessingError(PeerId, Ctx::Height),
}Variants
Tick
Internal tick
NetworkEvent(NetworkEvent<Ctx>)
Receive an even from gossip layer
Decided(Ctx::Height)
Consensus has decided on a value at the given height
StartedHeight(Ctx::Height, bool)
Consensus has (re)started a new height. The boolean indicates whether this is a restart or not.
GotDecidedValue(InboundRequestId, Ctx::Height, Option<RawDecidedValue<Ctx>>)
Host has a response for the blocks request
TimeoutElapsed(TimeoutElapsed<Timeout>)
A timeout has elapsed
InvalidValue(PeerId, Ctx::Height)
We received an invalid value (either certificate or value) from a peer
ValueProcessingError(PeerId, Ctx::Height)
An error occurred while processing a value